@@ -22,7 +22,7 @@
 ;; merchantability or fitness for a particular purpose.  See the GNU
 ;; Lesser General Public License for more details.
 ;;
-;; $Id: src.lisp 11030 2006-08-15 00:57:31Z kevin $
+;; $Id: src.lisp 11328 2006-12-02 15:43:07Z kevin $
 
 (defpackage #:puri
   (:use #:cl)
@@ -926,12 +926,12 @@ URI ~s contains illegal character ~s at position ~d."
 
 (defmethod print-object ((uri uri) stream)
   (if* *print-escape*
-     then (format stream "#<~a ~a>" 'uri (render-uri uri nil))
+     then (print-unreadable-object (uri stream :type t) (render-uri uri stream))
      else (render-uri uri stream)))
 
 (defmethod print-object ((urn urn) stream)
   (if* *print-escape*
-     then (format stream "#<~a ~a>" 'uri (render-urn urn nil))
+     then (print-unreadable-object (urn stream :type t) (render-urn urn stream))
      else (render-urn urn stream)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
