@@ -20,7 +20,7 @@
 ;; Original version from ACL 6.1:
 ;; t-uri.cl,v 1.3.6.3.2.1 2001/08/09 17:42:43 layer
 ;;
-;; $Id: tests.lisp 10882 2006-01-27 03:18:00Z kevin $
+;; $Id: tests.lisp 11031 2006-08-15 00:59:34Z kevin $
 
 
 (defpackage #:puri-tests (:use #:puri #:cl #:ptester))
@@ -183,9 +183,6 @@
     (push `(test "%20" (format nil "~a" (parse-uri "%20"))
 			   :test 'string=)
 	  res)
-     (push `(test "%FF" (format nil "~a" (parse-uri "%FF"))
-                          :test 'string=)
-         res) ;Value 255 outside reserved-chars vector (128 bits)
     (push `(test "&" (format nil "~a" (parse-uri "%26"))
 			   :test 'string=)
 	  res)
